@@ -40,6 +40,7 @@ module.exports = function getModelsMapForPopulate(model, docs, options) {
 
   for (i = 0; i < len; i++) {
     doc = docs[i];
+    let justOne = null;
 
     schema = getSchemaTypes(modelSchema, doc, options.path);
     // Special case: populating a path that's a DocumentArray unless
@@ -76,6 +77,7 @@ module.exports = function getModelsMapForPopulate(model, docs, options) {
           isRefPath = isRefPath || res.isRefPath;
           normalizedRefPath = normalizeRefPath(normalizedRefPath, doc, options.path) ||
             res.refPath;
+          justOne = res.justOne;
         } catch (error) {
           return error;
         }
@@ -99,6 +101,7 @@ module.exports = function getModelsMapForPopulate(model, docs, options) {
         modelNames = res.modelNames;
         isRefPath = res.isRefPath;
         normalizedRefPath = res.refPath;
+        justOne = res.justOne;
       } catch (error) {
         return error;
       }
@@ -142,7 +145,6 @@ module.exports = function getModelsMapForPopulate(model, docs, options) {
     // `justOne = null` means we don't know from the schema whether the end
     // result should be an array or a single doc. This can result from
     // populating a POJO using `Model.populate()`
-    let justOne = null;
     if ('justOne' in options && options.justOne !== void 0) {
       justOne = options.justOne;
     } else if (virtual && virtual.options && virtual.options.refPath) {
@@ -280,7 +282,12 @@ module.exports = function getModelsMapForPopulate(model, docs, options) {
           originalModel :
           modelName[modelSymbol] ? modelName : connection.model(modelName);
       } catch (error) {
-        return error;
+        // If `ret` is undefined, we'll add an empty entry to modelsMap. We shouldn't
+        // execute a query, but it is necessary to make sure `justOne` gets handled
+        // correctly for setting an empty array (see gh-8455)
+        if (ret !== undefined) {
+          return error;
+        }
       }
 
       let ids = ret;
@@ -339,6 +346,7 @@ module.exports = function getModelsMapForPopulate(model, docs, options) {
     let modelNames;
     let discriminatorKey;
     let isRefPath = false;
+    let justOne = null;
 
     if (schema && schema.caster) {
       schema = schema.caster;
@@ -407,6 +415,10 @@ module.exports = function getModelsMapForPopulate(model, docs, options) {
       const _virtualRes = getVirtual(modelForCurrentDoc.schema, options.path);
       const virtual = _virtualRes == null ? null : _virtualRes.virtual;
 
+      if (schemaForCurrentDoc != null) {
+        justOne = !schemaForCurrentDoc.$isMongooseArray && !schemaForCurrentDoc._arrayPath;
+      }
+
       let ref;
       let refPath;
 
@@ -440,14 +452,14 @@ module.exports = function getModelsMapForPopulate(model, docs, options) {
     }
 
     if (!modelNames) {
-      return { modelNames: modelNames, isRefPath: isRefPath, refPath: normalizedRefPath };
+      return { modelNames: modelNames, isRefPath: isRefPath, refPath: normalizedRefPath, justOne: justOne };
     }
 
     if (!Array.isArray(modelNames)) {
       modelNames = [modelNames];
     }
 
-    return { modelNames: modelNames, isRefPath: isRefPath, refPath: normalizedRefPath };
+    return { modelNames: modelNames, isRefPath: isRefPath, refPath: normalizedRefPath, justOne: justOne };
   }
 };
 
