@@ -605,7 +605,7 @@ class CoreMongooseArray extends Array {
 
     if (values[0] instanceof EmbeddedDocument) {
       this._registerAtomic('$pullDocs', values.map(function(v) {
-        return v._id || v;
+        return v.$__getValue('_id') || v;
       }));
     } else {
       this._registerAtomic('$pullAll', values);
@@ -703,7 +703,7 @@ class CoreMongooseArray extends Array {
   }
 
   /**
-   * Alias of [pull](#types_array_MongooseArray-pull)
+   * Alias of [pull](#mongoosearray_MongooseArray-pull)
    *
    * @see MongooseArray#pull #types_array_MongooseArray-pull
    * @see mongodb http://www.mongodb.org/display/DOCS/Updating/#Updating-%24pull
@@ -955,4 +955,4 @@ function _checkManualPopulation(arr, docs) {
   }
 }
 
-module.exports = CoreMongooseArray;
\ No newline at end of file
+module.exports = CoreMongooseArray;
